@@ -90,15 +90,7 @@ function(x, i, j)
         pos <- pos[or]
     }
 
-    # call directly .C("findInteval") because faster than
-    # i <- findInterval(ipos, pos)
-    if (!is.double(ipos)) ipos <- as.double(ipos)
-    if (!is.double(pos)) pos <- as.double(pos)
-    nx <- length(ipos)
-    i <- integer(nx)
-    .C("find_interv_vec", xt = pos, n = length(pos), x = ipos,
-       nx = nx, FALSE, FALSE, i, DUP = FALSE, NAOK = TRUE,
-       PACKAGE = "base")
+    i <- findInterval(ipos, pos)
 
     if (!identical(ipos, pos[i]))
         stop("subscript out of bounds", call. = FALSE)
@@ -543,13 +535,17 @@ setMethod("[", signature(x = "timeSeries", i = "time_timeSeries", j = "ANY"),
 # should behave the same way as $,data.frame
 
 setMethod("$", signature(x = "timeSeries"), function (x, name) {
-
     nc <- colnames(x)
     nr <- names(x@recordIDs)
     dataIdx <- pmatch(name, nc)
     recordIDsIdx <- pmatch(name, nr)
 
-    # if none or more than one match returns NULL
+    ## if none or more than one match return NULL.
+    ##
+    ## GNB: 'more than one match' is in the sense that 'name' has a match in
+    ##      both colnames(x) and names(x@recordIDs). Note that 'name is of
+    ##      length 1, the matches are of length one and there is no problem in
+    ##      the 'if'.
     if ((is.na(dataIdx) && is.na(recordIDsIdx)) ||
         (!is.na(dataIdx) && !is.na(recordIDsIdx)))
         return(NULL)
@@ -700,4 +696,3 @@ setReplaceMethod("[",
 
 
 ################################################################################
-
