@@ -58,7 +58,7 @@ setMethod("show", "timeSeries",
 
         # print message
         if (ptest)
-            cat(gettextf("...\n [ reached getRmetricsOption('max.print') | getOption('max.print') -- omitted %i rows ]]\n", omitted))
+            cat(gettextf("...\n [ reached getRmetricsOptions('max.print') | getOption('max.print') -- omitted %i rows ]]\n", omitted))
 
         # Return Value:
         invisible(NULL) # as specified in ?show
